==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Input/cdaudio/translations/cdaudio_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="45"/>
        <source>CD Audio Plugin</source>
        <translation>Wtyczka CD Audio</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="88"/>
        <source>About CD Audio Plugin</source>
        <translation>O wtyczce CD Audio</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="89"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Wtyczka CD Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Skompilowane przy użyciu libcdio-%1 oraz libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="92"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="93"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Instrukcja: otwórz cdda:/// używając Dodaj URL lib z linii poleceń</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Ustawienia wtyczki CD Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Wymuś urządzenie:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limid cd speed:</source>
        <translation>Limit prędkości cd:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>Użyj cd-text</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>Użyj HTTP zamiast CDDBP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>Serwer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Ścieżka:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>Wyczyść bufor CDDB</translation>
    </message>
</context>
</TS>

==> qmmp-0.6.8.tar.bz2: qmmp-0.6.8/src/plugins/Input/cdaudio/translations/cdaudio_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="45"/>
        <source>CD Audio Plugin</source>
        <translation>Wtyczka CD Audio</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="88"/>
        <source>About CD Audio Plugin</source>
        <translation>O wtyczce CD Audio</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="89"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Wtyczka CD Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Skompilowane przy użyciu libcdio-%1 oraz libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="92"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="93"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Instrukcja: otwórz cdda:/// używając Dodaj URL lib z linii poleceń</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Ustawienia wtyczki CD Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Wymuś urządzenie:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limit cd speed:</source>
        <translation>Limit prędkości cd:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>Użyj cd-text</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>Użyj HTTP zamiast CDDBP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>Serwer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Ścieżka:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>Wyczyść bufor CDDB</translation>
    </message>
</context>
</TS>
